featureflags.rest package
=========================

Subpackages
-----------

.. toctree::

    featureflags.rest.api
    featureflags.rest.models

Submodules
----------

featureflags.rest.client module
-------------------------------

.. automodule:: featureflags.rest.client
    :members:
    :undoc-members:
    :show-inheritance:

featureflags.rest.types module
------------------------------

.. automodule:: featureflags.rest.types
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: featureflags.rest
    :members:
    :undoc-members:
    :show-inheritance:
